summaryrefslogtreecommitdiff
path: root/png.c
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-10-19 20:31:31 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-10-19 20:36:57 -0500
commita2567be084ad9fd4f35360841f9e88cdfd2938c7 (patch)
tree0a3e9b7434a14346421f467a7bcb61f73b574a4b /png.c
parent614b91ded066f648a088235df4773f096bdf0c21 (diff)
downloadlibpng-a2567be084ad9fd4f35360841f9e88cdfd2938c7.tar.gz
[devel] Imported from libpng-1.4.0rc01.tar
Diffstat (limited to 'png.c')
-rw-r--r--png.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/png.c b/png.c
index 8b379dca4..065d9a4eb 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* Last changed in libpng 1.4.0 [October 10, 2009]
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -16,7 +16,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_0beta87 Your_png_h_is_not_version_1_4_0beta87;
+typedef version_1_4_0rc01 Your_png_h_is_not_version_1_4_0rc01;
/* Version information for C files. This had better match the version
* string defined in png.h.
@@ -547,13 +547,13 @@ png_get_copyright(png_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version x 1.4.0beta87 - October 10, 2009" PNG_STRING_NEWLINE \
+ "libpng version x 1.4.0rc01 - October 20, 2009" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2009 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.0beta87 - October 10, 2009\
+ return ((png_charp) "libpng version 1.4.0rc01 - October 20, 2009\
Copyright (c) 1998-2009 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.4.0 [October 10, 2009]
+ * Last changed in libpng 1.4.0 [October 20, 2009]
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)